@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Dpkg::PerlbrewStarman;
 {
-  $Dist::Zilla::Plugin::Dpkg::PerlbrewStarman::VERSION = '0.15';
+  $Dist::Zilla::Plugin::Dpkg::PerlbrewStarman::VERSION = '0.16';
 }
 use Moose;
 
@@ -51,12 +51,12 @@ APPDIR="/srv/$APP"
 APPLIB="/srv/$APP/lib"
 APPUSER={$package_name}
 
-PSGIAPP="script/$APP.psgi"
+PSGIAPP="{$psgi_script}"
 PIDFILE="/var/run/$APP.pid"
 
 PERLBREW_PATH="$APPDIR/perlbrew/bin"
 
-DAEMON_ARGS="-Ilib $PSGIAPP --daemonize --user $APPUSER --preload-app --workers 5 --pid $PIDFILE --port {$starman_port} --host 127.0.0.1 --error-log /var/log/$APP/error.log"
+DAEMON_ARGS="-Ilib $PSGIAPP --daemonize --user $APPUSER --preload-app --workers {$starman_workers} --pid $PIDFILE --port {$starman_port} --host 127.0.0.1 --error-log /var/log/$APP/error.log"
 '
 );
 
@@ -348,6 +348,22 @@ has 'starman_port' => (
 );
 
 
+has 'starman_workers' => (
+    is => 'ro',
+    isa => 'Str',
+    default => 5
+);
+
+
+has 'psgi_script' => (
+    is => 'ro',
+    isa => 'Str',
+    default => sub {
+        'script/'.$_[0]->package_name.'.psgi';
+    }
+);
+
+
 has 'startup_time' => (
     is => 'ro',
     isa => 'Str',
@@ -379,25 +395,27 @@ has 'apache_modules' => (
 around '_generate_file' => sub {
     my $orig = shift;
     my $self = shift;
-    
-    if($self->has_uid) {
-      $_[2]->{uid} = '--uid '.$self->uid;
-    }
-    
-    $_[2]->{starman_port} = $self->starman_port;
-    $_[2]->{startup_time} = $self->startup_time;
+	my $file = shift;
+	my $required = shift;
+	my $vars = shift;
 
-    $_[2]->{webserver_config_link} = '';
-    $_[2]->{webserver_restart} = '';
+    if($self->has_uid) {
+      $vars->{uid} = '--uid '.$self->uid;
+    }
+
+    $vars->{starman_port} = $self->starman_port;
+    $vars->{starman_workers} = $self->starman_workers;
+    $vars->{startup_time} = $self->startup_time;
 
     if(($self->web_server eq 'apache') || ($self->web_server eq 'all')) {
-        $_[2]->{webserver_config_link} .= '# Symlink to the apache config for the environment we`re in
+        $vars->{package_binary_depends} .= ', apache2';
+        $vars->{webserver_config_link} .= '# Symlink to the apache config for this environment
         rm -f /etc/apache2/sites-available/$PACKAGE
-        ln /srv/$PACKAGE/config/apache/$PACKAGE.conf /etc/apache2/sites-available/$PACKAGE
+        ln -s /srv/$PACKAGE/config/apache/$PACKAGE.conf /etc/apache2/sites-available/$PACKAGE
 ';
-        $_[2]->{webserver_restart} .= 'a2enmod proxy proxy_http rewrite ';
-		$_[2]->{webserver_restart} .= join ' ', @{ $self->apache_modules || [] };
-        $_[2]->{webserver_restart} .= '
+        $vars->{webserver_restart} .= 'a2enmod proxy proxy_http rewrite ';
+		$vars->{webserver_restart} .= join ' ', @{ $self->apache_modules || [] };
+        $vars->{webserver_restart} .= '
         a2ensite $PACKAGE
         mkdir -p /var/log/apache2/$PACKAGE
         if which invoke-rc.d >/dev/null 2>&1; then
@@ -408,20 +426,22 @@ around '_generate_file' => sub {
 ';
     }
     if(($self->web_server eq 'nginx') || ($self->web_server eq 'all')) {
-        $_[2]->{webserver_config_link} .= '# Symlink to the nginx config for the environment we`re in
+        $vars->{package_binary_depends} .= ', nginx';
+        $vars->{webserver_config_link} .= '# Symlink to the nginx config for this environment
         rm -f /etc/nginx/sites-available/$PACKAGE
         ln -s /srv/$PACKAGE/config/nginx/$PACKAGE.conf /etc/nginx/sites-available/$PACKAGE
 ';
-        $_[2]->{webserver_restart} .= 'if which invoke-rc.d >/dev/null 2>&1; then
+        $vars->{webserver_restart} .= 'if which invoke-rc.d >/dev/null 2>&1; then
             invoke-rc.d nginx restart
         else
             /etc/init.d/nginx restart
         fi
 ';
     }
-    $self->$orig(@_);
+    $self->$orig($file, $required, $vars);
 };
 
+
 1;
 
 __END__
@@ -433,72 +453,194 @@ Dist::Zilla::Plugin::Dpkg::PerlbrewStarman - Generate dpkg files for your perlbr
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
-  #  [Dpkg::PerlbrewStarman]
+A minimal directory structure for application foo:
+
+    lib/
+    root/
+    script/foo.psgi
+    config/nginx/foo.conf
+    perlbrew/bin/starman
+
+A minimal configuration:
+
+    [Dpkg::PerlbrewStarman]
+    web_server      = nginx
+    starman_port    = 6000
+
+A configuration showing optional attributes and their defaults:
+
+    [Dpkg::PerlbrewStarman]
+    web_server      = nginx
+    starman_port    = 6000
+    psgi_script     = script/foo.psgi
+    starman_workers = 5
+    startup_time    = 30
+
+A configuration showing optional attributes that have no defaults:
+
+    [Dpkg::PerlbrewStarman]
+    web_server      = apache
+    starman_port    = 6000
+    apache_modules  = ldap ssl
+    uid             = 782
 
 =head1 DESCRIPTION
 
-Dist::Zilla::Plugin::Dpkg::PerlbrewStarman is an extension of
-Dist::Zilla::Plugin::Dpkg. It generates Debian control files that are
-suitable for a perl app that includes it's own Perlbrew and runs under
-Starman.  It makes the following assumptions:
+This L<Dist::Zilla> plugin generates Debian control files that are
+suitable for packaging a self-contained Plack application utilizing the
+Starman preforking PSGI HTTP server.  Key features include supporting an
+independent perl environment and the generation and installation of init
+scripts to manage the service.
+
+Dist::Zilla::Plugin::Dpkg::PerlbrewStarman is an implementation of
+L<Dist::Zilla::Plugin::Dpkg>, which itself is an abstract base class
+more than anything.  It provides the basic framework by which this
+Dist::Zilla plugin builds the Debian control files.  If the desired
+functionality cannot be achieved by PerlbrewStarman, check there for
+other control templates that may be overridden.
+
+Dist::Zilla::Plugin::Dpkg::PerlbrewStarman provides defaults for the
+following L<Dist::Zilla::Plugin::Dpkg> stubs:
 
 =over 4
 
-=item XXX Perlbrew
+=item * conffiles_template_default
 
-=item Runs under L<Starman>
+=item * control_template_default
 
-=item Starman is fronted by nginx or apache
+=item * default_template_default
 
-=item It runs as a user called $packagename
+=item * init_template_default
 
-=item It's installed at /srv/$packagename
+=item * install_template_default
 
-=item Logs will be placed in /var/log/$packagename
+=item * postinst_template_default
 
-=item psgi file is in script and is named $packagename.psgi
-
-=item Config is in config/ and can be found by your app with nothing more than it's HOME variable set. (FOO_BAR_HOME)
-
-=item Nginx config is in config/nginx/$packagename.conf or Apache config is at config/apache/$packagename.conf
-
-=item Your app can be preloaded
-
-=item Your app only listens on localhost (nginx/apache handles the rest)
-
-=item You want 5 workers
+=item * postrm_template_default
 
 =back
 
-This module provides defaults for the following attribute:
+PerlbrewStarman is intended to be used to deploy applications that meet
+the following requirements:
 
 =over 4
 
-=item conffiles_template_default
+=item * L<perlbrew> -- others have reported using PerlbrewStarman under other systems (e.g., L<Carton>)
 
-=item control_template_default
+=item * Plack/PSGI using the L<Starman> preforking HTTP server listening on localhost
 
-=item default_template_default
+=item * Apache and/or nginx are utilized as front-end HTTP proxies
 
-=item init_template_default
+=item * Application may be preloaded (using Starman's --preload-app)
 
-=item install_template_default
-
-=item postinst_template_default
-
-=item postrm_template_default
+=item * Application does not require root privileges
 
 =back
 
+=head2 Directory structure
+
+The package is installed under C</srv/$PACKAGE>.  Though Debian policy
+generally forbids packages from installing into /srv, PerlbrewStarman
+was written for third-party distribution, not for inclusion into Debian.
+This may change.
+
+By default, your application must conform to the following directory
+structure:
+
+=over 4
+
+=item * perl environment in C<perlbrew>
+
+=item * application configuration in C<config>
+
+=item * Apache and/or nginx configuration in C<config/apache/$PACKAGE.conf> and/or C<config/nginx/$PACKAGE.conf>
+
+=item * PSGI and other application scripts in C<script>
+
+=item * application libraries in C<lib>
+
+=item * application templates in C<root>
+
+=back
+
+Only files located in these directories will be installed.  Additional
+files may be added to the is list by specifying a path to an alternative
+install control file using C<install_template>.  The default install
+template looks like this:
+
+    config/* srv/{$package_name}/config
+    lib/* srv/{$package_name}/lib
+    root/* srv/{$package_name}/root
+    script/* srv/{$package_name}/script
+    perlbrew/* srv/{$package_name}/perlbrew
+
+The package name is substituted for {$package_name} by Text::Template
+via L<Dist::Zilla::Plugin::Dpkg>.
+
+Paths may also be removed, but note that the only path in the default
+directory structure that is not utilized elsewhere by PerlbrewStarman
+is C<root/*>.
+
+=head2 Other paths
+
+PerlbrewStarman creates a number of files under C</etc> in order to
+integrate with init as well as the front-end HTTP proxy.  The directory
+C</var/log/$PACKAGE> and the link C</etc/$PACKAGE> are created as
+normalized locations for log files and app configuration, respectively.
+These paths should be intuitively familiar for most UNIX administrators.
+
+Following is a complete list of files and symlinks created:
+
+=over 4
+
+=item * /etc/init.d/$PACKAGE
+
+=item * /etc/default/$PACKAGE
+
+=item * /var/log/$PACKAGE
+
+=item * /etc/apache2/sites-available/$PACKAGE => /srv/$PACKAGE/config/apache/$PACKAGE.conf
+
+=item * /etc/nginx/sites-available/$PACKAGE => /srv/$PACKAGE/config/nginx/$PACKAGE.conf
+
+=item * /etc/$PACKAGE => /srv/$PACKAGE/config
+
+=back
+
+=head2 Environment
+
+By default, C</srv/$PACKAGE/perlbrew/bin> is prepended to the C<PATH> by
+way of the C<PERLBREW_PATH> variable in C</etc/default/$PACKAGE>.  The
+C<starman> binary must be present in the path, else the service will
+fail to start.
+
+The application runs as user $PACKAGE by way of the --user argument to
+L<Starman>.  Starman flags are specified by the C<DAEMON_ARGS> variable
+in C</etc/default/$PACKAGE>.
+
+=head1 SEE ALSO
+
+* L<Dist::Zilla::Plugin::ChangelogFromGit::Debian>
+* L<Dist::Zilla::Deb>
+
 =head1 ATTRIBUTES
 
 =head2 starman_port
 
-The port to use for starman.
+The port to use for starman (required).
+
+=head2 starman_workers
+
+The number of starman workers (5 by default).
+
+=head2 psgi_script
+
+Location of the psgi script started by starman. By default this is
+C<script/$PACKAGE.psgi>.
 
 =head2 startup_time
 
@@ -512,8 +654,8 @@ UIDs across multiple installations
 
 =head2 web_server
 
-Set the web server we'll be working with for this package.  Supported values
-are C<apache> and C<nginx>.
+Set the web server we'll be working with for this package (required).
+Supported values are C<apache>, C<nginx>, and C<all> for both..
 
 =head2 apache_modules
 
@@ -525,7 +667,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc.
+This software is copyright (c) 2013 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
